'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chai = require('chai');

var _nock = require('nock');

var _nock2 = _interopRequireDefault(_nock);

var _qs = require('qs');

var _qs2 = _interopRequireDefault(_qs);

var _formData = require('form-data');

var _formData2 = _interopRequireDefault(_formData);

var _dist = require('../dist');

var _dist2 = _interopRequireDefault(_dist);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
var logoFile = _path2.default.join(__dirname, '../../tests', 'assets/logo.png');

describe('post', function () {
  it('user3, by urlencoded', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /application\/x-www-form-urlencoded/
      }
    }).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).post('/user').query({
      uid: 3
    }).reply(200, function (uri, requestBody) {
      return Object.assign(_qs2.default.parse(requestBody), {
        status: 0
      });
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 3
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: {
        name: 'user3'
      },
      mergeHeaders: {
        poweredBy: 'X-Powered-By'
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.equal('user3');
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _chai.expect)(res.poweredBy).to.equal('nock');
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('user4, by JSON', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /json/
      }
    }).post('/user').query({
      uid: 4
    }).reply(200, function (uri, requestBody) {
      return Object.assign(requestBody, {
        status: 0
      });
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 4
      },
      headers: {
        'X-My-Headers': '1'
      },
      dataType: 'json',
      data: {
        name: 'user4'
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.equal('user4');
      (0, _chai.expect)(res.status).to.equal(0);
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('user5, by FormData', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /multipart\/form-data;\s*boundary=/
      }
    }).post('/user').query({
      uid: 5
    }).reply(200, function (uri, requestBody) {
      var body = Buffer.from(requestBody, 'hex').toString();
      return {
        status: 0,
        body: body
      };
    });
    var formData = new _formData2.default();
    formData.append('name', 'user5');
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 5
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: formData,
      FormData: _formData2.default
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _utils.checkFormData)(res.body, {
        name: function name(value) {
          (0, _chai.expect)(value).to.equal('user5');
        }
      });
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('user6, by form-data', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /multipart\/form-data;\s*boundary=/
      }
    }).post('/user').query({
      uid: 6
    }).reply(200, function (uri, requestBody) {
      var body = Buffer.from(requestBody, 'hex').toString();
      return {
        status: 0,
        body: body
      };
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 6
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: {
        name: 'user6'
      },
      dataType: 'form',
      FormData: _formData2.default
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _utils.checkFormData)(res.body, {
        name: function name(value) {
          (0, _chai.expect)(value).to.equal('user6');
        }
      });
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('user7, by files', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /multipart\/form-data;\s*boundary=/
      }
    }).post('/user').query({
      uid: 7
    }).reply(200, function (uri, requestBody) {
      var body = Buffer.from(requestBody, 'hex').toString();
      return {
        status: 0,
        body: body
      };
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 7
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: {
        name: 'user7',
        logo: _fs2.default.readFileSync(logoFile)
      },
      dataType: 'form',
      FormData: _formData2.default
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _utils.checkFormData)(res.body, {
        name: function name(value) {
          (0, _chai.expect)(value).to.equal('user7');
        },
        logo: function logo(value) {
          (0, _chai.expect)(value).to.equal('Content-Type: application/octet-stream');
        }
      });
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });

  it('user8, by FormData and files', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /multipart\/form-data;\s*boundary=/
      }
    }).post('/user').query({
      uid: 8
    }).reply(200, function (uri, requestBody) {
      var body = Buffer.from(requestBody, 'hex').toString();
      return {
        status: 0,
        body: body
      };
    });
    var formData = new _formData2.default();
    formData.append('name', 'user8');
    formData.append('files', _fs2.default.readFileSync(logoFile));
    formData.append('files', _fs2.default.readFileSync(logoFile));
    var fileCount = 0;
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 8
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: formData,
      FormData: _formData2.default
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _utils.checkFormData)(res.body, {
        name: function name(value) {
          (0, _chai.expect)(value).to.equal('user8');
        },
        files: function files(value) {
          fileCount++;
          (0, _chai.expect)(value).to.equal('Content-Type: application/octet-stream');
        }
      });
      (0, _chai.expect)(fileCount).to.equal(2);
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
});
//# sourceMappingURL=post.spec.js.map